"""

Thank You for using the PySpeedMacro library! 
This is my first ever python library so code may be spaghetti.
Please not that many new functions and updates will be posted as time progresses.

This was inspired by pyautogui and pydirectinput! 
I use these modules a lot, but I always wished I could have a faster more efficient code library.

PySpeedMacro provides, but is not limited to:

 - Mouse Control and Utility:
   - multiClick
   - leftClick
   - rightClick
   - getMousePosition
   - spinMouse
   - returnMouse

 - Image Search and Utility:

   - Screenshot
   - LocateOnScreen
   - LocateCenter
   - LocateAndMove
   -


2/27/2023

"""

__author__ = "BaneofRogue"
__version__ = "0.0.1"

from PySpeedMacro.PSMMouse import *
from PySpeedMacro.PSMMain import *
